==> haskell-css-text-0.1.3.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: css-text
version: 0.1.3.0
id: css-text-0.1.3.0-8Jq7NLak429ACTA4KHoQhd
key: css-text-0.1.3.0-8Jq7NLak429ACTA4KHoQhd
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: https://github.com/yesodweb/css-text.git#readme
synopsis: CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Text.CSS.Parse Text.CSS.Render
hidden-modules: Paths_css_text
abi: 050dc2fa4d1b7fed1b099a05a6929d66
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/css-text-0.1.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/css-text-0.1.3.0
hs-libraries: HScss-text-0.1.3.0-8Jq7NLak429ACTA4KHoQhd
depends:
    attoparsec-0.13.2.2-ImfqXHsnQ0kLjIvcUXLfco base-4.10.1.0
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
abi-depends: attoparsec-0.13.2.2-ImfqXHsnQ0kLjIvcUXLfco=02dde2665ea78b3a3aa2c59359e39730
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
haddock-interfaces: /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html: /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-css-text-0.1.3.0-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: css-text
version: 0.1.3.0
id: css-text-0.1.3.0-B3hyUXWA26b8iTWoXqj4zS
key: css-text-0.1.3.0-B3hyUXWA26b8iTWoXqj4zS
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: https://github.com/yesodweb/css-text.git#readme
synopsis: CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Text.CSS.Parse Text.CSS.Render
hidden-modules: Paths_css_text
abi: c7f9fc3401e75bc107d5ec6ad95884d5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/css-text-0.1.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/css-text-0.1.3.0
hs-libraries: HScss-text-0.1.3.0-B3hyUXWA26b8iTWoXqj4zS
depends:
    attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj base-4.10.1.0
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
abi-depends: attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj=9d8982f8b70cf41a2e1b007eb9382565
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
haddock-interfaces: /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html: /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
